import converters.*;
import java.io.*;
import java.util.*;
import java.text.*;
import javax.servlet.*;
import javax.servlet.http.*;

public class CurrencyConverter extends HttpServlet {

    private String format (Currency currency, double value) {
        NumberFormat nf = NumberFormat.getInstance();
	nf.setMaximumFractionDigits(currency.getDefaultFractionDigits());
        nf.setMinimumFractionDigits(currency.getDefaultFractionDigits());
	return nf.format(value);
    }

    public void doGet(HttpServletRequest req, HttpServletResponse res)
				 throws ServletException, IOException {

	Currency dollars = Currency.getInstance(Locale.US);
	Currency pounds = Currency.getInstance(Locale.UK);
	try {
	    double oldValue = Double.parseDouble(req.getParameter("amount"));
	    if (oldValue <= 0) {
	        req.setAttribute("error", "Value must be greater than zero");
	    }
	    else {
		try {
		    double exchangeRate =
		        new ConversionDAO().selectRate("USD","GBP");
		    double newValue = oldValue * exchangeRate ;
		    String result = dollars.getSymbol(Locale.US) +
		    format(dollars, oldValue) + " = " +
		        pounds.getSymbol(Locale.UK) + format(pounds, newValue);
		    req.setAttribute("result", result);
		}
		catch (Exception e)
		{
		    throw new ServletException();
		}
	    }
	    req.getRequestDispatcher ("/currency-form").forward(req, res);
	}
	catch (NumberFormatException e) {
	    req.setAttribute("error", "Non numeric value cannot be converted");
	    req.getRequestDispatcher ("/currency-form").forward(req, res);
	}
    }
}
