package converters;

import java.sql.*;
import java.text.*;
import java.util.*;
import javax.naming.*;
import javax.sql.*;

public class ConverterBean {
	private CurrencyFormat from;
	private CurrencyFormat to;
	private double exchangeRate = 1.0;

	public String getAmount() {
		return from.getAmount();
	}

	public void setAmount(String amount) throws ParseException {
		from.setAmount(amount);
	}

	public String getConvertedAmount() {
		to.setAmount(from.getDoubleAmount()*exchangeRate);
		return to.getAmount();
	}

	public String getConvertedAmount(String amount) throws ParseException {
		setAmount(amount);
		return getConvertedAmount();
	}

	public ConverterBean() throws SQLException, NamingException {
		getExchangeRate(Locale.US,Locale.UK);
	}

	public void setCountries (String src, String dst)
	throws SQLException, NamingException, IllegalArgumentException {
		Locale localeFrom = findLocale(src);
		if (localeFrom == null)
			throw new IllegalArgumentException("Unknown Country "+src);
		Locale localeTo = findLocale(dst);
		if (localeTo == null)
			throw new IllegalArgumentException("Unknown Country "+src);
	    getExchangeRate(localeFrom,localeTo);
    }

	private void getExchangeRate (Locale src, Locale dst)
	throws SQLException, NamingException {
	    from = new CurrencyFormat(src);
		to = new CurrencyFormat(dst);
		Connection con = null;
	    PreparedStatement select = null;
		ResultSet results = null;
		try {
		    Context init = new InitialContext();
		    Context ctx = (Context) init.lookup("java:comp/env");
		    DataSource ds = (DataSource) ctx.lookup("jdbc/conversion");
			con = ds.getConnection();
			select = con.prepareStatement(
		        "SELECT rate FROM Exchange WHERE src = ? AND dst = ?");
			select.setString(1,from.getCurrencyCode());
			select.setString(2,to.getCurrencyCode());
		    results = select.executeQuery();
			if (!results.next())
				throw new SQLException("Missing Exchange rate data row: "+
				                       from.getCurrencyCode()+","+
									   to.getCurrencyCode());
			exchangeRate = results.getDouble(1);
		}
		finally {
			try { results.close(); } catch (Exception ex) {}
			try { select.close(); } catch (Exception ex) {}
			try { con.close(); } catch (Exception ex) {}
		}
	}

	private Locale findLocale(String country) throws IllegalArgumentException {
		Locale[] locales = Locale.getAvailableLocales();
		for (int i=0; i<locales.length; i++) {
			if (locales[i].getDisplayCountry().equals(country))
				return locales[i];
		}
		throw new IllegalArgumentException("Unknown country name: "+country);
	}

	static private class CurrencyFormat {
		public CurrencyFormat(Locale where) {
			currency = Currency.getInstance(where);
			nf = NumberFormat.getInstance();
            nf.setMaximumFractionDigits(currency.getDefaultFractionDigits());
            nf.setMinimumFractionDigits(currency.getDefaultFractionDigits());
		}
		private Currency currency;
		private NumberFormat nf;

		private double amount;
		public String getAmount() {
			return currency.getSymbol()+ nf.format(amount);
		}

		public double getDoubleAmount() {
			return amount;
		}

		public void setAmount(String amount)  throws ParseException {
			if (amount != null)
				this.amount = nf.parse(amount).doubleValue();
		}

		public void setAmount(double amount) {
			this.amount = amount;
		}

		public String getCurrencyCode() {
			return currency.getCurrencyCode();
		}
	}
}