package converters;

import java.sql.*;
import java.text.*;
import java.util.*;
import javax.naming.*;
import javax.sql.*;

public class ConverterBean {
	private CurrencyFormat usd = new CurrencyFormat(Locale.US);
	private CurrencyFormat gbp = new CurrencyFormat(Locale.UK);
	private double exchangeRate = 1.0;


	public String getAmount() {
		return usd.getAmount();
	}

	public void setAmount(String amount)  throws ParseException {
		usd.setAmount(amount);
	}

	public String getConvertedAmount() {
		gbp.setAmount(usd.getDoubleAmount()*exchangeRate);
		return gbp.getAmount();
	}

	public String getConvertedAmount(String amount) throws ParseException {
		setAmount(amount);
		return getConvertedAmount();
	}

	public ConverterBean() throws SQLException, NamingException
	{
		Connection con = null;
	    PreparedStatement select = null;
		ResultSet results = null;
		try {
		    Context init = new InitialContext();
		    Context ctx = (Context) init.lookup("java:comp/env");
		    DataSource ds = (DataSource) ctx.lookup("jdbc/conversion");
			con = ds.getConnection();
			select = con.prepareStatement(
		        "SELECT rate FROM Exchange WHERE src = 'USD' AND dst = 'GBP'");
		    results = select.executeQuery();
			if (!results.next())
				throw new SQLException("Missing Exchange rate data row");
			exchangeRate = results.getDouble(1);
		}
		finally {
			try { results.close(); } catch (Exception ex) {}
			try { select.close(); } catch (Exception ex) {}
			try { con.close(); } catch (Exception ex) {}
		}
	}

	static private class CurrencyFormat {
		public CurrencyFormat(Locale where) {
			this.where = where;
			currency = Currency.getInstance(where);
			nf = NumberFormat.getInstance();
            nf.setMaximumFractionDigits(currency.getDefaultFractionDigits());
            nf.setMinimumFractionDigits(currency.getDefaultFractionDigits());
		}
		private Currency currency;
		private NumberFormat nf;
		private Locale where;

		private double amount;
		public String getAmount() {
			return currency.getSymbol(where)+ nf.format(amount);
		}

		public double getDoubleAmount() {
			return amount;
		}

		public void setAmount(String amount)  throws ParseException {
			if (amount != null)
				this.amount = nf.parse(amount).doubleValue();
		}

		public void setAmount(double amount) {
			this.amount = amount;
		}

		public String getCurrencyCode() {
			return currency.getCurrencyCode();
		}
	}
}
